@@ -8,6 +8,7 @@ WARNING =   '[WARNING] '
 FAILURE =   '[FAILURE] '
 WRAPPER =   '[WRAPPER] '
 ERROR =     '[ERROR  ] '
+TEST =      '[TEST   ] '
 
 BACK_SLASH = '\\'
 NEW_LINE = '\n'
@@ -62,6 +63,8 @@ CLOSE_SET = '}'
 LESSER = '<'
 BIGGER = '>'
 
+UNKNOWN = 'Unknown'
+
 TYPE_FUNCTION = 'function'
 TYPE_CLASS = 'class'
 TYPE_BOOLEAN = 'bool'
